@@ -4,7 +4,7 @@
    cppcomp.h : This file is part of pstoedit
    header declaring compiler dependent stuff
 
-   Copyright (C) 1998 - 2001 Wolfgang Glunz, wglunz@pstoedit.net
+   Copyright (C) 1998 - 2003 Wolfgang Glunz, wglunz@pstoedit.net
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -30,7 +30,7 @@
 #define DLLEXPORT
 #endif
 
-#if (defined (_MSC_VER) && _MSC_VER >= 1100) 
+#if defined (_MSC_VER) && (_MSC_VER >= 1100) 
 // MSVC 5 and 6 have ANSI C++ header files, but the compilation
 // is much slower and object files get bigger. 
 // add other compiler that support STL and the ANSI C++ standard here
@@ -38,22 +38,31 @@
 // NOTE: If your compiler or installation does not come with
 // an installation of the STL, just umcomment the next line
 
-// #define HAVESTL
-// #define HAVETYPENAME
+#define HAVESTL
+#define HAVETYPENAME
 // now this is again commented out by default, since now all
 // drivers can be compiled without the STL
 
 #endif
 
+#if defined (FORCESTLUSAGE)
+// 
+#define HAVESTL
+#define HAVETYPENAME
+#endif
+
 #if defined (__GNUG__)  && (__GNUC__>=3)
 // GNU 3.0 compiles in HAVESTL mode.
 // but is sooooooooooo slow
 // further, I had some crashes in this mode which don't occur in the traditional mode
 // so I finally commented this out again and made the code compile also in traditional mode
 #define HAVESTL
-
 #define HAVETYPENAME
 
+//#if (__GNUC__>=3)
+#define  USE_NEWSTRSTREAM
+//#endif
+
 #endif
 
 #ifdef __SUNPRO_CC
@@ -85,6 +94,7 @@
 //
 
 #ifdef HAVESTL
+
 #define I_fstream		<fstream>
 #define I_iomanip		<iomanip>
 #define I_ios			<ios>
@@ -102,7 +112,16 @@
 #define I_streamb       <iostream>
 #endif
 
+#ifdef  USE_NEWSTRSTREAM
+#define I_strstream 	<sstream>
+#define C_istrstream istringstream
+#define C_ostrstream ostringstream
+#else
 #define I_strstream 	<strstream>
+#define C_istrstream istrstream
+#define C_ostrstream ostrstream
+#endif
+
 
 #define I_stdio			<cstdio>
 #define I_stdlib		<cstdlib>
@@ -128,6 +147,9 @@
 #define I_strstream		<strstrea.h>
 #endif
 
+#define C_istrstream istrstream
+#define C_ostrstream ostrstream
+
 #if defined (__GNUG__) || defined (BOOLDEFINED) || ( defined (_MSC_VER) && _MSC_VER >= 1100) || defined (__BCPLUSPLUS__) && __BCPLUSPLUS__ >= 0x0400 || defined (INTERNALBOOL) || defined (_BOOL_EXISTS)
 // no need to define bool
 // 1100 is version 5.0
