@@ -2,7 +2,7 @@
    drvfuncs.h : This file is part of pstoedit
    This file contains the declarations of the functions, // each driver has to implement
 
-   Copyright (C) 1993 - 2001 Wolfgang Glunz, wglunz@pstoedit.net
+   Copyright (C) 1993 - 2003 Wolfgang Glunz, wglunz@pstoedit.net
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -27,11 +27,11 @@ private: // yes these are private, library users should use the public interface
 
 	void close_page();
 
-	void show_text(const TextInfo & textInfo);
-
 	void show_path(); 
 
-	void show_rectangle(const float llx, const float lly, const float urx, const float ury);
+//	void show_text(const TextInfo & textInfo);
+
+//	void show_rectangle(const float llx, const float lly, const float urx, const float ury);
 
 
  
