@@ -21,53 +21,19 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-
-    The base64 code is a modified version of the code in Python's
-    binascii module, which came with the following license:
-
-    Copyright 1991, 1992, 1993, 1994 by Stichting Mathematisch Centrum,
-Amsterdam, The Netherlands.
-
-                        All Rights Reserved
-
-Permission to use, copy, modify, and distribute this software and its
-documentation for any purpose and without fee is hereby granted,
-provided that the above copyright notice appear in all copies and that
-both that copyright notice and this permission notice appear in
-supporting documentation, and that the names of Stichting Mathematisch
-Centrum or CWI or Corporation for National Research Initiatives or
-CNRI not be used in advertising or publicity pertaining to
-distribution of the software without specific, written prior
-permission.
-
-While CWI is the initial source for this software, a modified version
-is made available by the Corporation for National Research Initiatives
-(CNRI) at the Internet address ftp://ftp.python.org.
-
-STICHTING MATHEMATISCH CENTRUM AND CNRI DISCLAIM ALL WARRANTIES WITH
-REGARD TO THIS SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF
-MERCHANTABILITY AND FITNESS, IN NO EVENT SHALL STICHTING MATHEMATISCH
-CENTRUM OR CNRI BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL
-DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR
-PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
-TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
-PERFORMANCE OF THIS SOFTWARE.
-
-
 */
 
-
+#include "cppcomp.h"
 #include <math.h>
-#include <stdlib.h>
+#include I_stdlib
 #include <ctype.h>
-#include <iomanip.h>
-#if (defined(unix) || defined(__unix__) || defined(_unix) || defined(__unix) || defined(__EMX__) || defined (NetBSD)  ) && !defined(DJGPP)
-#include <strstream.h>
-#else
-#include <strstrea.h>
-#endif
+#include I_iomanip
+
+#include I_strstream
+
 
 #include "drvsk.h"
+#include "base64writer.h"
 
 #ifndef PI
 #define PI 3.14159265358979323846264338327
@@ -252,7 +218,7 @@ void drvSK::show_path()
 
 void drvSK::show_rectangle(const float llx, const float lly, const float urx, const float ury)
 {
-	cerr << "Rectangle\n";
+	//cerr << "Rectangle\n";
 	outf << "r(" << urx - llx << ",0,0," << ury - lly << "," << llx << "," << lly << ")\n";
 }
 
@@ -292,92 +258,16 @@ bool drvSK::pathsCanBeMerged(const PathInfo & path1, const PathInfo & path2) con
 
 
 
-#define BASE64_MAXASCII 76		/* Max chunk size (76 char line) */
-
-static const unsigned char table_b2a_base64[] =
-	"ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/";
-
-#define FBUFLEN 2048
-#define BASE64_PAD '='
-
-int drvSK::write_base64(const unsigned char *buf, int length)
-{
-	unsigned char encoded[FBUFLEN];
-	unsigned char *ascii_data = encoded;
-	const unsigned char *bin_data = buf;
-	unsigned char this_ch;
-	int ascii_left;
-	int bin_len = ((FBUFLEN / 4) * 3);
-
-	if (bin_len > length)
-		bin_len = length;
-
-	/* first, fill the ascii buffer and don't care about max. line length */
-	for (; bin_len > 0; bin_len--, bin_data++) {
-		/* Shift the data into our buffer */
-		state.leftchar = (state.leftchar << 8) | *bin_data;
-		state.leftbits += 8;
-
-		/* See if there are 6-bit groups ready */
-		while (state.leftbits >= 6) {
-			this_ch = (state.leftchar >> (state.leftbits - 6)) & 0x3f;
-			state.leftbits -= 6;
-			*ascii_data++ = table_b2a_base64[this_ch];
-		}
-	}
-
-	/* now output the ascii data line by line */
-	ascii_left = ascii_data - encoded;
-	while (ascii_left > 0) {
-		int linelength = BASE64_MAXASCII - state.column;
-
-		if (ascii_left < linelength)
-			linelength = ascii_left;
-		outf.write((char *) (ascii_data - ascii_left), linelength);	// SUN CC needs this cast
-		ascii_left -= linelength;
-		state.column += linelength;
-		if (state.column >= BASE64_MAXASCII) {
-			outf.put('\n');
-			state.column = 0;
-		}
-	}
-	return bin_data - (const unsigned char *) buf;
-}
-
-void drvSK::close_base64()
-{
-	unsigned char buf[4];
-	unsigned char *ascii_data = buf;
-
-	if (state.leftbits == 2) {
-		*ascii_data++ = table_b2a_base64[(state.leftchar & 3) << 4];
-		*ascii_data++ = BASE64_PAD;
-		*ascii_data++ = BASE64_PAD;
-	} else if (state.leftbits == 4) {
-		*ascii_data++ = table_b2a_base64[(state.leftchar & 0xf) << 2];
-		*ascii_data++ = BASE64_PAD;
-	}
-
-	if (ascii_data > buf || state.column != 0) {
-		*ascii_data++ = '\n';	/* Append a courtesy newline */
-	}
-	if (ascii_data > buf) {
-		outf.write((char *) buf, ascii_data - buf);
-	}
-}
 
 
-
-
-
-void drvSK::show_image(const Image & imageinfo)
+void drvSK::show_image(const PSImage & imageinfo)
 {
 	if (imageinfo.ncomp > 3) {
 		cerr << "image with " << imageinfo.ncomp << " components not supported\n";
 		return;
 	}
 
-	ostrstream ppm;
+	C_ostrstream ppm;
 
 	switch (imageinfo.type) {
 	case colorimage:
@@ -414,23 +304,29 @@ void drvSK::show_image(const Image & imageinfo)
 	int imageid = getid();
 	outf << "bm(" << imageid << ")\n";
 
-	state.leftbits = 0;
-	state.leftchar = 0;
-	state.column = 0;
+	{
+	Base64Writer base64writer(outf);
 
-	write_base64((unsigned char *) ppm.str(), ppm.pcount());
-	// ppm.freeze(0);
+#ifdef  USE_NEWSTRSTREAM
+	string temp = ppm.str();
+	// basic_string<char, std::char_traits<char>, std::allocator<char> >	 temp = ppm.str();
+	const unsigned char * ppmdata = (const unsigned char*) temp.data();
+	base64writer.write_base64( ppmdata, temp.size());
+#else
+ 	base64writer.write_base64( (unsigned  char *) ppm.str(), ppm.pcount());
 	ppm.rdbuf()->freeze(0);
+#endif
 
 	int bytes_left = imageinfo.nextfreedataitem;
 	unsigned char *data = imageinfo.data;
 	while (bytes_left) {
-		int written = write_base64(data, bytes_left);
+		int written = base64writer.write_base64(data, bytes_left);
 		data += written;
 		bytes_left -= written;
 	}
 
-	close_base64();
+// now done in dtor --	base64writer.close_base64();
+	}
 
 	outf << "-\n";
 
@@ -451,9 +347,10 @@ static DriverDescriptionT < drvSK > D_sampl("sk", "Sketch Format", "sk", true,	/
 											true,	// backend supports curves
 											true,	// backend supports elements which are filled and stroked
 											true,	// backend supports text
-											true,	// backend supports Images
-											false,	// no support for PNG file images
+											DriverDescription::memoryeps,	// no support for PNG file images
 											DriverDescription::normalopen, false,	// if format supports multiple pages in one file
 											false, /*clipping */
 											nodriverspecificoptions);
  
+ 
+ 
