@@ -4,7 +4,7 @@
 
    Copyright (C) 1996,1997 Jens Weber, rz47b7@PostAG.DE
    Copyright (C) 1998 Thorsten Behrens and Bjoern Petersen
-   Copyright (C) 1998 - 2001 Wolfgang Glunz
+   Copyright (C) 1998 - 2003 Wolfgang Glunz
    Copyright (C) 2000 Thorsten Behrens
 
     This program is free software; you can redistribute it and/or modify
@@ -35,7 +35,6 @@
 #define M_PI		3.14159265358979323846
 #endif
 
-#include "pstoedit.h"
 
 
 //
@@ -85,16 +84,17 @@ struct PLACEABLEHEADER {
 
 static const OptionDescription driveroptions[] = {
 	OptionDescription("-m",0,"map to Arial"),
-	OptionDescription("-n",0,"emulate narrow fonts"),
+	OptionDescription("-nf",0,"emulate narrow fonts"),
 	OptionDescription("-b",0,"draw bounding box"),
 	OptionDescription("-p",0,"prune line ends"),
+	OptionDescription("-nb",0,"dont calculate and write bounding box"),
 	endofoptions};
 
 static	const char description[] = "generated by WMF/EMF backend of pstoedit\0input\0\0";
 
 drvWMF::derivedConstructor(drvWMF):
 constructBase, enhanced(false), mapToArial(false),
-emulateNarrowFonts(false), drawBoundingBox(true), pruneLineEnds(false)
+emulateNarrowFonts(false), drawBoundingBox(true), pruneLineEnds(false), narrowbox(true)
 {
 	// do some consistency checking
 	if (sizeof(PLACEABLEHEADER) != PLACEABLESIZE) {
@@ -110,7 +110,7 @@ emulateNarrowFonts(false), drawBoundingBox(true), pruneLineEnds(false)
 	}
 
 	desktopDC = GetDC(GetDesktopWindow());
-	tempName = NIL;
+//wogl	tempName = NIL;
 
 	// which output format?
 	if (strcmp(Pdriverdesc->symbolicname, "emf") == 0) {
@@ -123,9 +123,12 @@ emulateNarrowFonts(false), drawBoundingBox(true), pruneLineEnds(false)
 			mapToArial = true;
 		}
 		// emulate narrow fonts?
-		if (strstr(driveroptions_p, "-n") != NIL) {
+		if (strstr(driveroptions_p, "-nf") != NIL) {
 			emulateNarrowFonts = true;
 		}
+		if (strstr(driveroptions_p, "-nb") != NIL) {
+			narrowbox = false;
+		}
 		// shall we switch off drawing of bounding box?
 		if (strstr(driveroptions_p, "-b") != NIL) {
 			drawBoundingBox = false;
@@ -138,12 +141,12 @@ emulateNarrowFonts(false), drawBoundingBox(true), pruneLineEnds(false)
 
 	if (enhanced) {
 		// enhanced-Metafile (memory based) for W95/98 or NT
-#ifdef _WIN32
-		metaDC = CreateEnhMetaFile(desktopDC, NIL, NIL, NIL);
-#else
+		if (narrowbox) {
+			metaDC = CreateEnhMetaFile(desktopDC, NIL, NIL, NIL);
+		} else {
 	// under non Windowssystems we cannot use PlayEnhMetafile
-		metaDC = CreateEnhMetaFile(desktopDC, outFileName.value(), NIL, description);
-#endif
+			metaDC = CreateEnhMetaFile(desktopDC, outFileName.value(), NIL, description);
+		}
 		if (!metaDC) {
 			errf << "ERROR: could create enhanced metafile" << endl;
 			ctorOK = false;
@@ -154,7 +157,7 @@ emulateNarrowFonts(false), drawBoundingBox(true), pruneLineEnds(false)
 		tempName = full_qualified_tempnam("wmftemp");
 
 		// standard metafile for Win16
-		metaDC = CreateMetaFile(tempName);
+		metaDC = CreateMetaFile(tempName.value());
 		if (!metaDC) {
 			errf << "ERROR: could not open temporary metafile: " << tempName << endl;
 			ctorOK = false;
@@ -284,9 +287,9 @@ drvWMF::~drvWMF()
 
 		// create our final metafile (metaDC is reused)
 		// need to have two metafiles, because we know the output dimension just now
-#ifdef _WIN32
-		metaDC = CreateEnhMetaFile(desktopDC, outFileName.value(), NIL, description);
-#endif
+		if (narrowbox) {
+			metaDC = CreateEnhMetaFile(desktopDC, outFileName.value(), NIL, description);
+		}
 		if (metaDC) {
 			// set reasonable mapping mode (don't want distortion)
 			SetMapMode(metaDC, MM_ISOTROPIC);
@@ -309,12 +312,12 @@ drvWMF::~drvWMF()
 //          const RECT  bbox = {minX, maxY, maxX-minX, maxY-minY};
 //          const RECT  bbox = {minX, maxY, maxX+2*minX, -minY-maxY};
 
-#ifdef _WIN32
+			if (narrowbox) {
 			// replay recorded metafile
-			if (!PlayEnhMetaFile(metaDC, hMeta, &bbox)) {
-				errf << "ERROR: cannot replay created metafile" << endl;
+				if (!PlayEnhMetaFile(metaDC, hMeta, &bbox)) {
+					errf << "ERROR: cannot replay created metafile" << endl;
+				}
 			}
-#endif
 			// close and commit metafile
 			DeleteEnhMetaFile(CloseEnhMetaFile(metaDC));
 		} else {
@@ -333,7 +336,7 @@ drvWMF::~drvWMF()
 		WORD checksum;
 		WORD *checksumField;
 
-		if ((inFile = fopen(tempName, "rb")) != 0L) {
+		if ((inFile = fopen(tempName.value(), "rb")) != 0L) {
 			if (outFile != 0L) {
 				// setup header
 				pHd.key = PLACEABLEKEY;
@@ -374,9 +377,9 @@ drvWMF::~drvWMF()
 
 			fclose(inFile);
 		}
-		remove(tempName);
-		free(tempName);
-		tempName = NIL;
+		remove(tempName.value());
+//wogl		free(tempName);
+//		tempName = NIL;
 	}
 
 	// delete desktop DC (might need it above)
@@ -976,7 +979,7 @@ void drvWMF::show_rectangle(const float llx, const float lly, const float urx, c
 }
 
 
-void drvWMF::show_image(const Image & image)
+void drvWMF::show_image(const PSImage & image)
 {
 	// first retrieve bounding box
 	Point lowerLeft, upperRight;
@@ -994,7 +997,7 @@ void drvWMF::show_image(const Image & image)
 	const long width  = abs(i_transX(upperRight.x_) - i_transX(lowerLeft.x_));
 	const long height = abs(i_transY(upperRight.y_) - i_transY(lowerLeft.y_));
 
-	if (verbose) {
+	if (Verbose()) {
 		cout << "image.Width:" << image.width << " image.Height: " << image.height << endl;
 		cout << "Width:" << width << " Height: " << height << endl;
 	}
@@ -1131,39 +1134,28 @@ void drvWMF::show_image(const Image & image)
 	}
 
 	// draw Windows DI bitmap
-	BITMAPINFO *bmi;
+	BITMAPINFO bmi;
 
-	if ((bmi = new BITMAPINFO)) {
-		/* setup BITMAPINFO */
-		bmi->bmiHeader.biSize = sizeof(BITMAPINFOHEADER);
-		bmi->bmiHeader.biWidth = width;
-		bmi->bmiHeader.biHeight = height;
-		bmi->bmiHeader.biPlanes = 1;
-		bmi->bmiHeader.biBitCount = 24;	// always truecolor output
-		bmi->bmiHeader.biClrUsed = 0;
-		bmi->bmiHeader.biCompression = BI_RGB;
-		bmi->bmiHeader.biSizeImage = 0;	/* size not important */
-		bmi->bmiHeader.biXPelsPerMeter = 0;	/* size not important */
-		bmi->bmiHeader.biYPelsPerMeter = 0;	/* size not important */
-		bmi->bmiHeader.biClrImportant = 0;
+			/* setup BITMAPINFO */
+		bmi.bmiHeader.biSize = sizeof(BITMAPINFOHEADER);
+		bmi.bmiHeader.biWidth = width;
+		bmi.bmiHeader.biHeight = height;
+		bmi.bmiHeader.biPlanes = 1;
+		bmi.bmiHeader.biBitCount = 24;	// always truecolor output
+		bmi.bmiHeader.biClrUsed = 0;
+		bmi.bmiHeader.biCompression = BI_RGB;
+		bmi.bmiHeader.biSizeImage = 0;	/* size not important */
+		bmi.bmiHeader.biXPelsPerMeter = 0;	/* size not important */
+		bmi.bmiHeader.biYPelsPerMeter = 0;	/* size not important */
+		bmi.bmiHeader.biClrImportant = 0;
 
-		if (SetDIBitsToDevice(metaDC,
+		if (!SetDIBitsToDevice(metaDC,
 							  l_transX(lowerLeft.x_),
 							  l_transY(upperRight.y_),
-							  width, height, 0, 0, 0, height, output, bmi, DIB_RGB_COLORS)) {
-			delete bmi;
-			delete[]output;
-
-			// done
-			return;
+							  width, height, 0, 0, 0, height, output, &bmi, DIB_RGB_COLORS)) {
+			errf << "ERROR: Cannot draw bitmap" << endl;
 		}
-
-		delete bmi;
-	}
-
 	delete[]output;
-
-	errf << "ERROR: Cannot draw bitmap" << endl;
 }
 
 
@@ -1184,8 +1176,7 @@ static DriverDescriptionT < drvWMF > D_wmf("wmf", "Windows metafile", "wmf", tru
 										   false,	// backend does not support curves (at least for WMF - have to take least common denominator here)
 										   true,	// backend supports elements which are filled and have edges 
 										   true,	// backend supports text
-										   true,	// backend supports Images
-										   false,	// no support for PNG file images
+										   DriverDescription::memoryeps,	// no support for PNG file images
 										   DriverDescription::noopen,	// we open output file ourselves
 										   false,	// if format supports multiple pages in one file (DEFINETELY not) 
 										   false, /*clipping */ 
@@ -1207,10 +1198,10 @@ static DriverDescriptionT < drvWMF > D_emf("emf", "Enhanced Windows metafile", "
 										   false,	// backend does not support curves (not yet)
 										   true,	// backend supports elements which are filled and have edges 
 										   true,	// backend supports text
-										   true,	// backend supports Images
-										   false,	// no support for PNG file images
+										   DriverDescription::memoryeps,	// no support for PNG file images
 										   DriverDescription::noopen,	// we open output file ourselves
 										   false,	// if format supports multiple pages in one file (DEFINETELY not) 
 										   false, /*clipping */
 										   driveroptions);
  
+ 
