@@ -2,7 +2,7 @@
    dynload.h : This file is part of pstoedit
    declarations for dynamic loading of drivers
 
-   Copyright (C) 1993 - 2001 Wolfgang Glunz, wglunz@pstoedit.net
+   Copyright (C) 1993 - 2003 Wolfgang Glunz, wglunz@pstoedit.net
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -27,7 +27,7 @@ class DynLoader
 public:
 	typedef void (*fptr)(); // any signature possible, but is has to be a function pointer.
 							// the new standard does not allow to mix normal and function pointers.
-	DynLoader(const char * libname_P = 0);
+	DynLoader(const char * libname_P = 0, int verbose_p = 0);
 	~DynLoader();
 	void open(const char * libname);
 	void close();
@@ -37,6 +37,7 @@ public:
 private:
 	const char * libname;
 	void* handle;	
+	int verbose;
 };
 
 #ifdef HAVESTL
@@ -47,8 +48,9 @@ class ostream;
 #endif
 #ifndef LEANDYNLOAD
 // lean - just the dlopen/dlclose stuff
-void loadPlugInDrivers(const char * pluginDir,ostream& errstream);
+void loadPlugInDrivers(const char * pluginDir,ostream& errstream,bool verbose);
 #endif 
  
  
  
+ 
