@@ -1,8 +1,10 @@
+#ifndef PSTOEDIT_H
+#define PSTOEDIT_H
 /*
    pstoedit.h : This file is part of pstoedit
    main control procedure
 
-   Copyright (C) 1993 - 2001 Wolfgang Glunz, wglunz@pstoedit.net
+   Copyright (C) 1993 - 2003 Wolfgang Glunz, wglunz@pstoedit.net
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -19,17 +21,22 @@
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
 */
+
+#ifdef __cplusplus
+/* for C++ users more functions are available than for C users */ 
+
+
 #ifndef cppcomp_h
 #include "cppcomp.h"
 #endif
 
-//#include <iostream.h>
+/* #include <iostream.h>   */
 #ifdef HAVESTL
 #include <iosfwd>
 USESTD
 #else
 #if defined (__GNUG__)  && (__GNUC__>=3) 
-// if we dont define HAVESTL for g++ > 3.0, then we can use the simple forwards
+/* if we dont define HAVESTL for g++ > 3.0, then we can use the simple forwards */
 	#include <iostream.h>
 #else
 	class istream;
@@ -37,13 +44,21 @@ USESTD
 #endif
 #endif
 
-typedef int (*execute_interpreter_function)(int argc, const char * const argv[]);
-typedef const char * (*whichPI_type)(ostream &,int);
+/* end of cplusplus */
+#endif
 
+#include "pstoedll.h"
+
+typedef int (*execute_interpreter_function)(int argc, const char * const argv[]);
+
+
+
+#ifdef __cplusplus
+typedef const char * (*whichPI_type)(ostream &,int);
 
 class DescriptionRegister;
 
-// for "C" functions we cannot use "bool"
+/* for "C" functions we cannot use "bool"   */
 
 extern "C" DLLEXPORT 
 int pstoedit(	int argc,
@@ -61,24 +76,58 @@ int pstoeditwithghostscript(int argc,
 							const DescriptionRegister* const pushinsPtr=0
 							);
 
+#endif
+
+#ifdef __cplusplus
 extern "C" DLLEXPORT 
+#endif
 int pstoedit_plainC(int argc,
 					const char * const argv[],
-					const char * const psinterpreter  // if 0, then pstoedit will look for one using whichpi()
+					const char * const psinterpreter  /* if 0, then pstoedit will look for one using whichpi() */
 					);
 
-struct DriverDescription_S;
+/* extern "C" DLLEXPORT const class DriverDescription* const * getPstoeditDriverInfo(ostream& errstream); */
+#ifdef __cplusplus
+extern "C" DLLEXPORT 
+#endif
+struct DriverDescription_S* getPstoeditDriverInfo_plainC(void);
+//
+// function to clear the memory allocated by the getPstoeditDriverInfo_plainC
+// function. This avoids conflicts with different heaps.
+//
+#ifdef __cplusplus
+extern "C" DLLEXPORT 
+#endif
+void clearPstoeditDriverInfo_plainC(struct DriverDescription_S * ptr);
 
-//extern "C" DLLEXPORT const class DriverDescription* const * getPstoeditDriverInfo(ostream& errstream);
-extern "C" DLLEXPORT DriverDescription_S* getPstoeditDriverInfo_plainC(void);
-extern "C" DLLEXPORT int pstoedit_checkversion (unsigned int callersversion);									 
-void ignoreVersionCheck(void); // not exported to the DLL interface, just used internally
+
+#ifdef __cplusplus
+extern "C" DLLEXPORT 
+#endif
+struct DriverDescription_S* getPstoeditNativeDriverInfo_plainC(void); /* for the pstoedit native drivers - not the ones that are provided as short cuts to ghostscript */
+
+
+#ifdef __cplusplus
+extern "C" DLLEXPORT 
+#endif
+int pstoedit_checkversion (unsigned int callersversion);
+									 
+void ignoreVersionCheck(void); /* not exported to the DLL interface, just used internally */
+
+
+#ifdef __cplusplus
 
 #if defined(_WIN32) || defined(__OS2__)
 #include "cbstream.h"
 extern "C" DLLEXPORT void setPstoeditOutputFunction(void * cbData,write_callback_type* cbFunction);
 #endif
 
+#endif
+
+
+#endif
+
+ 
  
  
  
